<?php

namespace Drupal\forum_notifications_subscription\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Component\Datetime\TimeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form controller for Frequency edit forms.
 *
 * @ingroup forum_notification
 */
class ForumNotificationFrequencyForm extends ContentEntityForm {

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Constructs a new ForumNotificationFrequencyForm object.
   *
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
   *   The entity repository service.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entity_type_bundle_info
   *   The entity type bundle service.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger service.
   */
  public function __construct(EntityRepositoryInterface $entity_repository, EntityTypeBundleInfoInterface $entity_type_bundle_info, TimeInterface $time, MessengerInterface $messenger) {
    parent::__construct($entity_repository, $entity_type_bundle_info, $time);
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity.repository'),
      $container->get('entity_type.bundle.info'),
      $container->get('datetime.time'),
      $container->get('messenger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\forum_notifications_subscription\Entity\Frequency $entity */
    $form = parent::buildForm($form, $form_state);

    $form['name']['#disabled'] = TRUE;
    $form['type']['#disabled'] = TRUE;
    $form['entity_id']['#disabled'] = TRUE;
    $form['entity_name']['#disabled'] = TRUE;
    $form['frequency']['widget'][0]['value'] = [
      '#type' => 'select',
      '#default_value' => $this->entity->getFrequency() ?? 'Daily Digest Emails',
      '#options' => [
        'Daily Digest Emails' => $this->t('Daily Digest Emails'),
        'Single Emails' => $this->t('Single Emails'),
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state): int {
    $entity = &$this->entity;
    $entity_label = $entity->label() ?? '';
    $entity_name_field = $entity->entity_name->value ?? '';
    $status = parent::save($form, $form_state);

    switch ($status) {
      case SAVED_NEW:
        $this->messenger->addMessage($this->t('Created the %entity_name frequency for %label.', [
          '%entity_name' => $entity_name_field,
          '%label' => $entity_label,
        ]));
        break;

      default:
        $this->messenger->addMessage($this->t('Saved the %entity_name frequency for %label.', [
          '%entity_name' => $entity_name_field,
          '%label' => $entity_label,
        ]));
    }
    $form_state->setRedirect('entity.forum_notification_frequency.canonical', ['forum_notification_frequency' => $entity->id()]);

    return $status;
  }

}
