<?php

namespace Drupal\forum_notifications_subscription;

/**
 * Interface for forum notification subscription services.
 *
 * Defines the contract for services that manage forum notification
 * subscriptions, including operations for creating, checking, and
 * deleting notification frequency settings for users.
 */
interface ForumNotificationsSubscriptionServiceInterface {

  /**
   * Checks notification frequency for a given entity.
   *
   * Retrieves the notification frequency configuration for the current user
   * and the specified entity (forum topic or forum).
   *
   * @param int|\Drupal\Core\Entity\ContentEntityInterface $entity_id
   *   The entity ID or entity object to check notification frequency for.
   *
   * @return \Drupal\Core\Entity\EntityInterface|null
   *   The notification frequency entity if found, NULL otherwise.
   */
  public function checkNotificationFrequencyByEntity($entity_id);

  /**
   * Creates a notification frequency entity for the current user.
   *
   * Establishes a new notification subscription for the current user
   * on the specified entity with default frequency settings.
   *
   * @param int $entity_id
   *   The ID of the entity to create notification for.
   * @param string $entity_type_id
   *   The entity type ID ('node' for forum topics; 'taxonomy_term' for forums).
   */
  public function createNotificationFrequencyByEntity($entity_id, $entity_type_id);

  /**
   * Deletes notification frequency for current user by entity ID.
   *
   * Removes the notification subscription for the current user
   * from the specified entity.
   *
   * @param int $entity_id
   *   The ID of the entity to delete notification frequency for.
   */
  public function deleteNotificationFrequencyByEntity($entity_id);

}
