<?php

namespace Drupal\forum_notifications_subscription;

use Drupal\Core\Utility\Token;

/**
 * Service for handling token replacement in forum notification messages.
 *
 * This service provides a wrapper around Drupal's core token service
 * specifically for forum notification subscription functionality,
 * enabling dynamic token replacement in notification messages.
 */
class ForumNotificationsSubscriptionTokenService {

  /**
   * The core token service.
   *
   * @var \Drupal\Core\Utility\Token
   */
  private $tokenService;

  /**
   * Constructs a new ForumNotificationsSubscriptionTokenService object.
   *
   * @param \Drupal\Core\Utility\Token $tokenService
   *   The core token service for token replacement operations.
   */
  public function __construct(Token $tokenService) {
    $this->tokenService = $tokenService;
  }

  /**
   * Replaces tokens in plain text with their corresponding values.
   *
   * This method processes a plain text string containing tokens and replaces
   * them with actual values based on the provided data context. Commonly used
   * for generating personalized forum notification messages.
   *
   * @param string $plain
   *   The plain text string containing tokens to be replaced.
   * @param array $data
   *   An associative array of token data. Keys should be token types
   *   (e.g., 'user', 'node', 'term') and values should be the corresponding
   *   entity objects or data arrays.
   *
   * @return string
   *   The text with tokens replaced by their corresponding values.
   *
   * @see \Drupal\Core\Utility\Token::replacePlain()
   */
  public function replacePlain(string $plain, array $data) {
    return $this->tokenService->replacePlain($plain, $data);
  }

}
